/*
------------------------------------------------------------
   Kobo Deluxe - An enhanced SDL port of XKobo
------------------------------------------------------------
 * Copyright (C) 2001, David Olofson
 * 
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "config.h"
#include "cfgform.h"
#include "sounds.h"


config_form_t::config_form_t()
{
	prf = NULL;
	stat = 0;
}


config_form_t::~config_form_t()
{
}


void config_form_t::open(prefs_t *p)
{
	DBG(printf("config_form_t::open()\n");)
	prf = p;
	prfbak = *p;
	stat = 0;
	build_all();
//	SDL_EnableKeyRepeat(KOBO_KEY_DELAY, KOBO_KEY_REPEAT);
}


void config_form_t::close()
{
//	SDL_EnableKeyRepeat(0, 0);
	clean();
}


void config_form_t::undo()
{
	*prf = prfbak;
	stat = 0;
}


int config_form_t::status()
{
	return stat;
}


void config_form_t::clearstatus(int mask)
{
	stat &= ~mask;
}


/*virtual*/ void config_form_t::change(int delta)
{
	kobo_form_t::change(delta);

	if(!selected())
		return;

	if(selected()->tag & OS_CLOSE)
	{
		if(delta == 0)
		{
			play_sound(SOUND_EXPL);
			stat |= OS_CLOSE;
		}
	}
	else if(selected()->tag & OS_CANCEL)
	{
		if(delta == 0)
		{
			play_sound(SOUND_SHOT);
			undo();
			stat |= OS_CLOSE;
		}
	}
	else
		play_sound(SOUND_METALLIC);

	if(delta)
		stat |= selected()->tag & (OS_RELOAD | OS_RESTART | OS_UPDATE);

	if(selected()->user)
	{
		int *val = (int *)selected()->user;
		*val = selected()->value();
		DBG(printf("Changed to %d\n", selected()->value());)
		prf->changed = 1;
	}

	switch(prf->width)
	{
	  case 320: prf->height = 240; break;
	  case 400: prf->height = 300; break;
	  case 512: prf->height = 384; break;
	  case 640: prf->height = 480; break;
	  case 800: prf->height = 600; break;
	  case 960: prf->height = 720; break;
	  case 1024: prf->height = 768; break;
	  case 1152: prf->height = 864; break;
	  case 1280: prf->height = 1024; break;
	}

	if(selected()->tag & OS_REBUILD)
	{
		int sel = selected_index();
		build_all();
		select(sel);
	}
}

/* virtual */void config_form_t::build()
{
}
