/*
 * Simple "GUI" toolkit for config screens.
 *  David Olofson, 2001
 */

/*
 * Note: change(0) means "apply", and would be the normal
 *       result of pressing enter while a widget is selected.
 */

#include "window.h"


class ct_widget_t : public window_t
{
  protected:
	friend class ct_form_t;
	int		interactive;
	int		transparent;
	int		highlighted;
	Uint32		_color;
	int		_value;
	int		_widget_index;
	virtual void render();
  public:
	ct_widget_t	*next, *prev;	//*CIRCULAR* list!
	void		*user;	//user stuff
	int		tag;	//user stuff
	ct_widget_t();
	virtual void init(gfxengine_t *e);
	void transparency(int t);
	void highlight(int hl);
	void color(Uint32 _cl);
	virtual void change(int delta);
	virtual void value(int val);
	virtual int value();
};


class ct_engine_t
{
  public:
	ct_engine_t();
	void (*render_highlight)(ct_widget_t *wg);
};

extern ct_engine_t ct_engine;


class ct_label_t : public ct_widget_t
{
  protected:
	char	_caption[64];
	virtual void render();
  public:
	ct_label_t(const char *cap = NULL);
	void caption(const char *cap);
	const char *caption()	{ return _caption; }
};


class ct_item_t
{
  protected:
	char	_caption[64];
	int	_index;
	int	_value;
  public:
	ct_item_t	*next, *prev;	//*CIRCULAR* list!
	ct_item_t(const char *cap = NULL, int val = 0);
	void caption(const char *cap);
	const char *caption()	{ return _caption; }
	void value(int val)	{ _value = val; }
	int value()		{ return _value; }
	void index(int i)	{ _index = i; }
	int index()		{ return _index; }
};

class ct_list_t : public ct_label_t
{
  protected:
	ct_item_t	*items;
	ct_item_t	*_selected;
	virtual void render();
  public:
	ct_list_t(const char *cap = NULL);
	virtual ~ct_list_t();
	void add(ct_item_t *item);
	void add(const char *cap, int val);
	void clean();
	void select(ct_item_t *item);
	void select(int index);
	ct_item_t *selected();
	virtual void value(int val);
	virtual int value();
	virtual void change(int delta);
};


class ct_spin_t : public ct_label_t
{
  protected:
	int	min;
	int	max;
	virtual void render();
  public:
	ct_spin_t(const char *cap = NULL, int _min = 0, int _max = 99999);
	virtual void value(int val);
	virtual void change(int delta);
};


class ct_button_t : public ct_label_t
{
  protected:
	virtual void render();
  public:
	ct_button_t(const char *cap = NULL);
	virtual void change(int delta);
};


class ct_form_t : public window_t
{
  protected:
	ct_widget_t	*widgets;
	ct_widget_t	*_selected;
  public:
	ct_form_t();
	virtual ~ct_form_t();
	void add(ct_widget_t *w);
	void clean();
	virtual void select(ct_widget_t *w);
	virtual void select(int index);
	virtual void next();
	virtual void prev();
	ct_widget_t *selected();
	int selected_index();
	void render();
	virtual void change(int delta);
};
