/*
------------------------------------------------------------
	glSDL - SDL style blitting API on top of OpenGL
		Ugly Proof-of-Concept Hack
------------------------------------------------------------
 * (c) David Olofson, 2001
 * This code is released under the terms of the GNU LGPL.
 */

#ifdef HAVE_OPENGL

#define	_GLSDL_NO_REDEFINES_
#include "glSDL.h"

#include <string.h>
#include <stdlib.h>

#ifdef WIN32
#include <windows.h>
#endif
#if defined(__APPLE__) && defined(__MACH__)
#include <OpenGL/gl.h>
#include <OpenGL/glu.h>
#else
#include <GL/gl.h>
#include <GL/glu.h>
#endif

#define	USING_GLSDL	(IS_GLSDL_SURFACE(SDL_GetVideoSurface()))


#if 0
/* Internal struct to manage one OpenGL texture */
typedef struct _glSDL_Bank
{
	GLint	texture;	/* OpenGL texture ID */
	int	w, h;		/* Texture size */
	int	tw, th;		/* Tile size */
} _glSDL_Bank;


typedef struct _glSDL_Rect
{
	GLfloat	x, y;
	GLfloat	w, h;
} _glSDL_Rect;
#endif


static SDL_PixelFormat _RGBfmt, _RGBAfmt;
static int update_screen = 0;

#if 0
static void _print_glerror()
{
	char *err = "<unknown>";
	switch(glGetError())
	{
	  case GL_NO_ERROR:
		return;
	  case GL_INVALID_ENUM:
		err = "GL_INVALID_ENUM";
		break;
	  case GL_INVALID_VALUE:
		err = "GL_INVALID_VALUE";
		break;
	  case GL_INVALID_OPERATION:
		err = "GL_INVALID_OPERATION";
		break;
	  case GL_STACK_OVERFLOW:
		err = "GL_STACK_OVERFLOW";
		break;
	  case GL_STACK_UNDERFLOW:
		err = "GL_STACK_UNDERFLOW";
		break;
	  case GL_OUT_OF_MEMORY:
		err = "GL_OUT_OF_MEMORY";
		break;
	}
	fprintf(stderr,"OpenGL error: %s\n", err);
}
#endif

/* Add a glSDL_TexInfo struct to an SDL_Surface */
static int glSDL_AddTexInfo(SDL_Surface *surface, int w, int h)
{
	glSDL_TexInfo *txi;
	if(!surface)
		return -1;
	if(IS_GLSDL_SURFACE(surface))
		return 0;	/* Do nothing */

	txi = calloc(1, sizeof(glSDL_TexInfo));
	if(!txi)
		return -1;

	txi->used.w = txi->lw = w;
	txi->used.h = txi->lh = h;
	txi->texture = -1;

	SDL_SetClipRect(surface, &txi->used);

	/* This is the nasty part: */
	surface->unused1 = (Uint32)txi;

	return 0;
}


/* Create a surface of the prefered OpenGL RGB texture format */
static SDL_Surface *_CreateRGBSurface(int w, int h)
{
	SDL_Surface *s;
	int rmask, gmask, bmask, bits;
	int ts;
	for(ts = 1; ts < w; ts <<= 1)
		;
	for(; ts < h; ts <<= 1)
		;
	bits = 24;
#if SDL_BYTEORDER == SDL_BIG_ENDIAN
	rmask = 0x00ff0000;
	gmask = 0x0000ff00;
	bmask = 0x000000ff;
#else
	rmask = 0x000000ff;
	gmask = 0x0000ff00;
	bmask = 0x00ff0000;
#endif
	s = SDL_CreateRGBSurface(SDL_SWSURFACE, ts, ts,
			bits, rmask, gmask, bmask, 0);;
	if(s)
		GLSDL_FIX_SURFACE(s);

	glSDL_AddTexInfo(s, w, h);
	return s;
}


/* Create a surface of the prefered OpenGL RGBA texture format */
static SDL_Surface *_CreateRGBASurface(int w, int h)
{
	SDL_Surface *s;
	int rmask, gmask, bmask, amask, bits;
	int ts;
	for(ts = 1; ts < w; ts <<= 1)
		;
	for(; ts < h; ts <<= 1)
		;
	bits = 32;
#if SDL_BYTEORDER == SDL_BIG_ENDIAN
	rmask = 0xff000000;
	gmask = 0x00ff0000;
	bmask = 0x0000ff00;
	amask = 0x000000ff;
#else
	rmask = 0x000000ff;
	gmask = 0x0000ff00;
	bmask = 0x00ff0000;
	amask = 0xff000000;
#endif
	s = SDL_CreateRGBSurface(SDL_SWSURFACE, ts, ts,
			bits, rmask, gmask, bmask, amask);;
	if(s)
		GLSDL_FIX_SURFACE(s);

	glSDL_AddTexInfo(s, w, h);
	return s;
}


static void _init_formats()
{
	SDL_Surface *s = _CreateRGBSurface(1, 1);
	if(!s)
		return;
	_RGBfmt = *(s->format);
	SDL_FreeSurface(s);

	s = _CreateRGBASurface(1, 1);
	if(!s)
		return;
	_RGBAfmt = *(s->format);
	SDL_FreeSurface(s);
}


static void _key2alpha(SDL_Surface *surface)
{
	int x, y;
	Uint32 ckey = surface->format->colorkey;
	if(SDL_LockSurface(surface) < 0)
		return;

	for(y = 0; y < surface->h; ++y)
	{
		Uint32 *px = (Uint32 *)(surface->pixels + y*surface->pitch);
		for(x = 0; x < surface->w; ++x)
			if(px[x] == ckey)
				px[x] = 0;
	}
	SDL_UnlockSurface(surface);
}



/*----------------------------------------------------------
	SDL style API
----------------------------------------------------------*/

SDL_Surface *glSDL_SetVideoMode(int width, int height, int bpp, Uint32 flags)
{
	SDL_Surface *screen;
	GLint gl_doublebuf;
	if(!(flags & SDL_GLSDL))
	{
		screen = SDL_SetVideoMode(width, height, bpp, flags);
		if(screen)
			GLSDL_FIX_SURFACE(screen);
		return screen;
	}

	flags &= ~SDL_GLSDL;

	/*
	 * Doesn't seem to slow anything down unless we
	 * lock/unlock the screen surface - and that's
	 * when it's required!
	 *
	 * The only problem is that SDL does only half
	 * the job. It won't read the *actual* frame
	 * buffer. Does "kind of" handle pixel level
	 * access to the screen, though.
	 */
	flags |= SDL_OPENGLBLIT;

	gl_doublebuf = flags & SDL_DOUBLEBUF;
	if(bpp == 15)
	{
		SDL_GL_SetAttribute(SDL_GL_RED_SIZE, 5);
		SDL_GL_SetAttribute(SDL_GL_GREEN_SIZE, 5);
		SDL_GL_SetAttribute(SDL_GL_BLUE_SIZE, 5);
	}
	if(bpp == 16)
	{
		SDL_GL_SetAttribute(SDL_GL_RED_SIZE, 5);
		SDL_GL_SetAttribute(SDL_GL_GREEN_SIZE, 6);
		SDL_GL_SetAttribute(SDL_GL_BLUE_SIZE, 5);
	}
	else if(bpp >= 24)
	{
		SDL_GL_SetAttribute(SDL_GL_RED_SIZE, 8);
		SDL_GL_SetAttribute(SDL_GL_GREEN_SIZE, 8);
		SDL_GL_SetAttribute(SDL_GL_BLUE_SIZE, 8);
	}
	SDL_GL_SetAttribute(SDL_GL_DEPTH_SIZE, bpp);
	SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER, gl_doublebuf);

	screen = SDL_SetVideoMode(width, height, bpp, flags);
	if(!screen)
		return NULL;

	GLSDL_FIX_SURFACE(screen);

	_init_formats();

	if(glSDL_AddTexInfo(screen, width, height) < 0)
	{
		fprintf(stderr, "glSDL: Failed to add info to screen surface!\n");
		SDL_QuitSubSystem(SDL_INIT_VIDEO);
		return NULL;
	}

	glSDL_SetLogicSize(screen, width, height);
	return screen;
}


void glSDL_Quit()
{
	if(SDL_WasInit(SDL_INIT_VIDEO))
		SDL_QuitSubSystem(SDL_INIT_VIDEO);
}


void _glSDL_FullQuit()
{
	glSDL_Quit();
	SDL_Quit();
}


void glSDL_UpdateRects(SDL_Surface *screen, int numrects, SDL_Rect *rects)
{
	if(!update_screen && IS_GLSDL_SURFACE(screen))
		glSDL_Flip(screen);
	else
		SDL_UpdateRects(screen, numrects, rects);
	update_screen = 0;
}


void glSDL_UpdateRect(SDL_Surface *screen, Sint32 x, Sint32 y, Uint32 w, Uint32 h)
{
	if(!update_screen && IS_GLSDL_SURFACE(screen))
		glSDL_Flip(screen);
	else
		SDL_UpdateRect(screen, x, y, w, h);
	update_screen = 0;
}


int glSDL_Flip(SDL_Surface *screen)
{
	if(!IS_GLSDL_SURFACE(screen))
		return SDL_Flip(screen);
/*
TODO:	Perform all rendering here, after globally reordering/optimizing
	all non-overlapping operations for the frame. (Reduce texture
	changes, blend mode changes etc...)
*/

	/*
	 * Some XFree86 DRI drivers won't sync *at all*
	 * without glFinish()! You may end up with commands
	 * for several frames buffered up before any actual
	 * rendering is done - and then, your program will
	 * stall until most of the rendering is completed.
	 *
	 * (Of course, this wouldn't be much of an issue
	 * if the drivers did retrace sync'ed flips, but as
	 * most of the drivers don't, there's no way ever an
	 * application is going to get smooth animation
	 * without this kludge.)
	 */
	glFlush();	/* Just in case. *heh* */
	SDL_GL_SwapBuffers();
	glFinish();	/* And here we kill parallel execution... :-( */
	return 0;
}


void glSDL_FreeSurface(SDL_Surface *surface)
{
	if(!surface)
		return;
	if(IS_GLSDL_SURFACE(surface))
	{
		glSDL_UnloadSurface(surface);
		free(TEXINFO(surface));
	}
	SDL_FreeSurface(surface);
}


int glSDL_LockSurface(SDL_Surface *surface)
{
	if(!surface)
		return 0;
	if(SDL_GetVideoSurface() != surface)
	{
		if(IS_GLSDL_SURFACE(surface))
			glSDL_Invalidate(surface, NULL);
	}
	return SDL_LockSurface(surface);
}


void glSDL_UnlockSurface(SDL_Surface *surface)
{
	if(!surface)
		return;
	SDL_UnlockSurface(surface);
	if(IS_GLSDL_SURFACE(surface))
	{
		if(SDL_GetVideoSurface() != surface)
			glSDL_DownloadSurface(surface);
		else
		{
			update_screen = 1;	/* SDL will deal with this */

			/*
			 * ...or so I thought! Misses the first
			 * 256x256 tile, though.
			 */
			SDL_UpdateRect(surface, 0, 0, 0, 0);
		}
	}
}


int glSDL_SetColorKey(SDL_Surface *surface, Uint32 flag, Uint32 key)
{
	int res = SDL_SetColorKey(surface, flag, key);
	if(res < 0)
		return res;

	if(IS_GLSDL_SURFACE(surface))
	{
		glSDL_UnloadSurface(surface);
		if(flag & SDL_SRCCOLORKEY)
			if(surface->format->Amask)
				_key2alpha(surface);
	}
	return res;
}


int glSDL_SetAlpha(SDL_Surface *surface, Uint32 flag, Uint8 alpha)
{
	/*
	 * This is just parameters to OpenGL, so the actual
	 * "work" is done in glSDL_BlitSurface().
	 */
	return SDL_SetAlpha(surface, flag, alpha);
}


SDL_bool glSDL_SetClipRect(SDL_Surface *surface, SDL_Rect *rect)
{
	SDL_bool res;
	if(!surface)
		return SDL_FALSE;

	res = SDL_SetClipRect(surface, rect);
	if(!res)
		return SDL_FALSE;

	if( (SDL_GetVideoSurface() == surface) &&
			IS_GLSDL_SURFACE(surface) )
	{
		float xscale, yscale;
		glSDL_TexInfo *txi = TEXINFO(surface);
		rect = &surface->clip_rect;

		glViewport(rect->x, rect->y, rect->w, rect->h);

		glMatrixMode(GL_PROJECTION);
		glLoadIdentity();
		/* Note that this projection is upside down in
		 * relation to the OpenGL coordinate system. */
		xscale = (float)txi->lw / (float)surface->w;
		yscale = (float)txi->lh / (float)surface->h;
		glOrtho(	xscale*(float)rect->x,
				xscale*(float)(rect->w+rect->x),
				yscale*(float)(rect->h+rect->y),
				yscale*(float)rect->y,
				-1.0, 1.0);

		return SDL_TRUE;
	}
	return res;
}


static struct
{
	int	do_blend;
	int	do_texture;
	GLint	texture;
	GLenum	sfactor, dfactor;
} glstate;

static void gl_reset()
{
	glstate.do_blend = -1;
	glstate.do_blend = -1;
	glstate.texture = -1;
	glstate.sfactor = -1;
	glstate.dfactor = -1;
}

static inline void gl_do_blend(int on)
{
	if(glstate.do_blend == on)
		return;

	if(on)
		glEnable(GL_BLEND);
	else
		glDisable(GL_BLEND);
	glstate.do_blend = on;
}

static inline void gl_do_texture(int on)
{
	if(glstate.do_texture == on)
		return;

	if(on)
		glEnable(GL_TEXTURE_2D);
	else
		glDisable(GL_TEXTURE_2D);
	glstate.do_texture = on;
}

static inline void gl_blendfunc(GLenum sfactor, GLenum dfactor)
{
	if(sfactor == glstate.sfactor)
		return;
	if(dfactor == glstate.dfactor)
		return;

	glBlendFunc(sfactor, dfactor);

	glstate.sfactor = sfactor;
	glstate.dfactor = dfactor;
}

static inline void gl_texture(GLint tx)
{
	if(tx != glstate.texture)
	{
		glBindTexture(GL_TEXTURE_2D, tx);
		glstate.texture = tx;
	}
}


static int _glSDL_BlitFromGL(SDL_Surface *src, SDL_Rect *srcrect,
			 SDL_Surface *dst, SDL_Rect *dstrect)
{
	glSDL_Invalidate(dst, dstrect);
	/* This doesn't work. SDL never reads the real framebuffer. */
	return SDL_BlitSurface(src, srcrect, dst, dstrect);
}


static int _glSDL_BlitGL(SDL_Surface *src, SDL_Rect *srcrect,
			 SDL_Surface *dst, SDL_Rect *dstrect)
{
	int using_temp = 0;
	glSDL_TexInfo *txi;
	float x1, y1, x2, y2;
	int dx1, dy1, dx2, dy2;
	if(!src || !dst)
		return -1;

	/* Make sure we have a source with a valid texture */
	glSDL_DownloadSurface(src);
	txi = TEXINFO(src);

#if 0
	if(IS_GLSDL_SURFACE(src))
 	{
		txi = TEXINFO(src);
		if(txi->invalid_area.w || (txi->texture == -1))
			glSDL_DownloadSurface(src);
	}
	else
	{
		/*
		 * Ouch! Nasty. Last resort: Create a temporary surface
		 * with an OpenGL texture format, download it, use it, and
		 * then unload it and throw the surface away. *heh*
		 *
		 * (If we trap all legal access to every SDL surface, we
		 * can implement an automatic caching system; invalidate
		 * a texture only if it's surface has been modified. For
		 * now, we just throw textures and surfaces away after
		 * rendering.)
		 */
		if(src->format->Amask)
			src = glSDL_DisplayFormatAlpha(src);
		else
			src = glSDL_DisplayFormat(src);
		if(!src)
			return -1;
		using_temp = 1;
		txi = TEXINFO(src);
	}
#endif

	/* Set up blending */
	if(src->flags & (SDL_SRCALPHA | SDL_SRCCOLORKEY))
	{
		gl_blendfunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
		gl_do_blend(1);
	}
	else
		gl_do_blend(0);

	/* Select texture */
	gl_texture(txi->texture);
	gl_do_texture(1);

	/* Calculate texcoords */
	if(!srcrect)
		srcrect = &txi->used;
	x1 = (float)srcrect->x / (float)src->w;
	y1 = (float)srcrect->y / (float)src->h;
	x2 = (float)(srcrect->x+srcrect->w) / (float)src->w;
	y2 = (float)(srcrect->y+srcrect->h) / (float)src->h;

	/* Calculate screen coords. */
	dx2 = (int)(x2 - x1)*(float)txi->lw;
	dy2 = (int)(y2 - y1)*(float)txi->lh;
	if(dstrect)
	{
		dx1 = dstrect->x;
		dy1 = dstrect->y;
		dstrect->w = dx2;
		dstrect->h = dy2;
	}
	else
		dx1 = dy1 = 0;
	dx2 += dx1;
	dy2 += dy1;

	/* Render! */
	glBegin(GL_QUADS);
	if((src->flags & SDL_SRCALPHA) &&
			(!src->format->Amask || (src->flags & SDL_SRCCOLORKEY)))
		glColor4ub(255, 255, 255, src->format->alpha);
	else
		glColor4f(1.0, 1.0, 1.0, 1.0);
	glTexCoord2f(x1, y1);
	glVertex2i(dx1, dy1);
	glTexCoord2f(x2, y1);
	glVertex2i(dx2, dy1);
	glTexCoord2f(x2, y2);
	glVertex2i(dx2, dy2);
	glTexCoord2f(x1, y2);
	glVertex2i(dx1, dy2);
	glEnd();

	if(using_temp)
		glSDL_FreeSurface(src);

	return 0;
}


int glSDL_BlitSurface(SDL_Surface * src, SDL_Rect * srcrect,
		SDL_Surface * dst, SDL_Rect * dstrect)
{
	SDL_Surface *vs;
	if(!src || !dst)
		return -1;

	/*
	 * Figure out what to do:
	 *      Not using glSDL:        SDL_BlitSurface()
	 *      screen->screen:         _glSDL_BlitFromGL() + _glSDL_BlitGL()
	 *      surface->screen:        _glSDL_BlitGL()
	 *      screen->surface:        _glSDL_BlitFromGL()
	 *      surface->surface:       SDL_BlitSurface()
	 */
	if(!USING_GLSDL)
		return SDL_BlitSurface(src, srcrect, dst, dstrect);

	vs = SDL_GetVideoSurface();
	if(src == vs)
	{
		if(dst == vs)
		{
			printf("glSDL_BlitSurface(): screen->screen"
					" blits not yet implemented!\n");
			return -1;
		}
		else
		{
			return _glSDL_BlitFromGL(src, srcrect,
					dst, dstrect);
		}
	}
	else
	{
		if(dst == vs)
		{
			return _glSDL_BlitGL(src, srcrect,
					dst, dstrect);
		}
		else
		{
			glSDL_Invalidate(dst, dstrect);
			return SDL_BlitSurface(src, srcrect, dst, dstrect);
		}
	}
}


int glSDL_FillRect(SDL_Surface *dst, SDL_Rect *dstrect, Uint32 color)
{
	int dx1, dy1, dx2, dy2;
	Uint32 r, g, b;

	if(SDL_GetVideoSurface() != dst)
		glSDL_Invalidate(dst, dstrect);

	if((SDL_GetVideoSurface() != dst) || !USING_GLSDL)
		return SDL_FillRect(dst, dstrect, color);

	gl_do_texture(0);
	gl_do_blend(0);

	if(!dstrect)
		dstrect = &dst->clip_rect;

	dx1 = dstrect->x;
	dy1 = dstrect->y;
	dx2 = dx1 + dstrect->w;
	dy2 = dy1 + dstrect->h;

	r = color & dst->format->Rmask;
	r = r >> dst->format->Rshift;
	r = r << dst->format->Rloss;

	g = color & dst->format->Gmask;
	g = g >> dst->format->Gshift;
	g = g << dst->format->Gloss;

	b = color & dst->format->Bmask;
	b = b >> dst->format->Bshift;
	b = b << dst->format->Bloss;

	glBegin(GL_QUADS);
	glColor3ub(r, g, b);
	glVertex2i(dx1, dy1);
	glVertex2i(dx2, dy1);
	glVertex2i(dx2, dy2);
	glVertex2i(dx1, dy2);
	glEnd();

	return 0;
}


SDL_Surface *glSDL_DisplayFormat(SDL_Surface *surface)
{
	SDL_Surface *s, *tmp;
	if(USING_GLSDL)
	{
		if(surface->flags & SDL_SRCCOLORKEY)
			tmp = SDL_ConvertSurface(surface, &_RGBAfmt, SDL_SWSURFACE);
		else
			tmp = SDL_ConvertSurface(surface, &_RGBfmt, SDL_SWSURFACE);
		if(!tmp)
			return NULL;
		GLSDL_FIX_SURFACE(tmp);

		if(surface->flags & SDL_SRCCOLORKEY)
		{
			/*
			 * We drop colorkey data here, but we have to,
			 * or we'll run into trouble when converting,
			 * in particular from indexed color formats.
			SDL_SetColorKey(tmp, SDL_SRCCOLORKEY,
					surface->format->colorkey);
			 */
			_key2alpha(tmp);
		}

		SDL_SetAlpha(tmp, 0, 0);
		SDL_SetColorKey(tmp, 0, 0);
		if(surface->flags & SDL_SRCCOLORKEY)
			s = _CreateRGBASurface(surface->w, surface->h);
		else
			s = _CreateRGBSurface(surface->w, surface->h);
		if(!s)
		{
			glSDL_FreeSurface(tmp);
			return NULL;
		}
		SDL_BlitSurface(tmp, NULL, s, NULL);
		glSDL_FreeSurface(tmp);

		if(surface->flags & SDL_SRCALPHA)
			SDL_SetAlpha(s, SDL_SRCALPHA,
					surface->format->alpha);
		return s;
	}
	else
	{
		s = SDL_DisplayFormat(surface);
		if(s)
			GLSDL_FIX_SURFACE(s);
		return s;
	}
}


SDL_Surface *glSDL_DisplayFormatAlpha(SDL_Surface *surface)
{
	SDL_Surface *s, *tmp;
	if(USING_GLSDL)
	{
		tmp = SDL_ConvertSurface(surface, &_RGBAfmt, SDL_SWSURFACE);
		if(!tmp)
			return NULL;
		GLSDL_FIX_SURFACE(tmp);

		SDL_SetAlpha(tmp, 0, 0);
		SDL_SetColorKey(tmp, 0, 0);
		s = _CreateRGBASurface(surface->w, surface->h);
		if(!s)
		{
			glSDL_FreeSurface(tmp);
			return NULL;
		}
		SDL_BlitSurface(tmp, NULL, s, NULL);
		glSDL_FreeSurface(tmp);

		if(surface->flags & SDL_SRCCOLORKEY)
		{
			SDL_SetColorKey(s, SDL_SRCCOLORKEY,
					surface->format->colorkey);
			_key2alpha(s);
		}
		if(surface->flags & SDL_SRCALPHA)
			SDL_SetAlpha(s, SDL_SRCALPHA,
					surface->format->alpha);
		return s;
	}
	else
	{
		s = SDL_DisplayFormatAlpha(surface);
		if(s)
			GLSDL_FIX_SURFACE(s);
		return s;
	}
}


SDL_Surface *glSDL_ConvertSurface
			(SDL_Surface *src, SDL_PixelFormat *fmt, Uint32 flags)
{
	SDL_Surface *s = SDL_ConvertSurface(src, fmt, flags);
	if(s)
		GLSDL_FIX_SURFACE(s);
	return s;
}


SDL_Surface *glSDL_CreateRGBSurface
			(Uint32 flags, int width, int height, int depth, 
			Uint32 Rmask, Uint32 Gmask, Uint32 Bmask, Uint32 Amask)
{
	SDL_Surface *s = SDL_CreateRGBSurface(flags, width, height, depth, 
			Rmask, Gmask, Bmask, Amask);
	if(s)
		GLSDL_FIX_SURFACE(s);
	return s;
}


SDL_Surface *glSDL_CreateRGBSurfaceFrom(void *pixels,
			int width, int height, int depth, int pitch,
			Uint32 Rmask, Uint32 Gmask, Uint32 Bmask, Uint32 Amask)
{
	SDL_Surface *s = SDL_CreateRGBSurfaceFrom(pixels,
			width, height, depth, pitch,
			Rmask, Gmask, Bmask, Amask);
	if(s)
		GLSDL_FIX_SURFACE(s);
	return s;
}


SDL_Surface *glSDL_LoadBMP(const char *file)
{
	SDL_Surface *s = SDL_LoadBMP(file);
	if(s)
		GLSDL_FIX_SURFACE(s);
	return s;
}




/*----------------------------------------------------------
	glSDL specific API extensions
----------------------------------------------------------*/

void glSDL_Invalidate(SDL_Surface *surface, SDL_Rect *area)
{
	glSDL_TexInfo *txi;
	if(!surface)
		return;
	if(!IS_GLSDL_SURFACE(surface))
		return;
	txi = TEXINFO(surface);
	if(!area)
	{
		txi->invalid_area.x = 0;
		txi->invalid_area.y = 0;
		txi->invalid_area.w = surface->w;
		txi->invalid_area.h = surface->h;
		return;
	}
	txi->invalid_area = *area;
}


void glSDL_SetLogicSize(SDL_Surface *surface, int w, int h)
{
	SDL_Rect r;
	glSDL_TexInfo *txi;
	if(!IS_GLSDL_SURFACE(surface))
		return;
	
	txi = TEXINFO(surface);

	txi->lw = w;
	txi->lh = h;

	if(SDL_GetVideoSurface() != surface)
		return;

	r.x = r.y = 0;
	r.w = w;
	r.h = h;
	glSDL_SetClipRect(surface, &r);

	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
	glTranslatef(0.0f, 0.0f, 0.0f);

	glDisable(GL_DEPTH_TEST);
	glDisable(GL_CULL_FACE);
	
	gl_reset();
}


/*
 * Actually, this should be called something along
 * the lines of "MakeSureTextureIsValid(), at least
 * internally...
 */
void glSDL_DownloadSurface(SDL_Surface *surface)
{
	SDL_Surface *datasurf = surface;
	glSDL_TexInfo *txi;

	/*
	 * For now, we just assume that *every* texture needs
	 * conversion before downloading.
	 */

	/* If there's no TexInfo, add one. */
	if(!IS_GLSDL_SURFACE(surface))
		glSDL_AddTexInfo(surface, surface->w, surface->h);

	txi = TEXINFO(surface);

	/* No partial updates implemented yet... */
	if(txi->invalid_area.w)
		glSDL_UnloadSurface(surface);

	if(txi->texture != -1)
		return;		/* Ok, it's already there... --> */

	/* Convert into temporary surface. */
	if(surface->format->Amask)
		datasurf = glSDL_DisplayFormatAlpha(surface);
	else
		datasurf = glSDL_DisplayFormat(surface);
	if(!datasurf)
		return;

	/* Rip the texture info from the converted surface */
	txi->used = TEXINFO(datasurf)->used;

	glGenTextures(1, &txi->texture);
	glBindTexture(GL_TEXTURE_2D, txi->texture);
	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
	if(surface->format->Amask)
		glTexImage2D(GL_TEXTURE_2D, 0, 4, datasurf->w, datasurf->h, 0,
				GL_RGBA, GL_UNSIGNED_BYTE, datasurf->pixels);
	else
		glTexImage2D(GL_TEXTURE_2D, 0, 3, datasurf->w, datasurf->h, 0,
				GL_RGB, GL_UNSIGNED_BYTE, datasurf->pixels);

	if(datasurf != surface)
		glSDL_FreeSurface(datasurf);
}


void glSDL_UnloadSurface(SDL_Surface *surface)
{
	glSDL_TexInfo *txi;
	if(!IS_GLSDL_SURFACE(surface))
		return;

	txi = TEXINFO(surface);
	glDeleteTextures(1, &txi->texture);
	memset(&txi->invalid_area, 0, sizeof(txi->invalid_area));
	txi->texture = -1;
}

#endif GLSDL_OFF
